@@ -26,6 +26,7 @@ from django.templatetags.static import static
 from django.utils import timezone
 
 from . import models
+
 from .lib import ConfigManager
 from .lib import DatabaseManager
 from .lib import DeploymentManager
@@ -42,6 +43,8 @@ from .lib.exception import TeslaMissingEnrolmentException
 from .lib.exception import TeslaMissingICException
 from .lib.exception import TeslaVaultException
 
+from .models.user import get_institution_roles, get_institution_user
+
 #: Client instance
 _client = None
 
@@ -314,6 +317,10 @@ class Client():
             # Generate Moodle administrator password
             config.set('MOODLE_ADMIN_PASSWORD', uuid.uuid4().__str__())
 
+        # Check that output folder exists
+        if not os.path.exists(os.path.dirname(output_file)):
+            os.makedirs(os.path.dirname(output_file))
+
         # Write the configuration file to disk
         with open(output_file, 'w') as out_fh:
             config.write(out_fh)
@@ -548,6 +555,28 @@ class Client():
 
         raise TeslaAuthException('Invalid JWT token')
 
+    def change_user_password(self, email, password):
+        """
+            Change user credentials
+
+            :param email: The user email
+            :type email: str
+            :param password: The user password
+            :type password: str
+        """
+        try:
+            user = models.User.objects.get(email=email)
+            if settings.TESLA_PASSWORD_BACKEND == 'DJANGO':
+                user.set_password(password)
+                user.save()
+            if settings.TESLA_PASSWORD_BACKEND == 'VAULT':
+                # TODO: Create Vault instance
+                pass
+        except TeslaVaultException:
+            raise TeslaAuthException('Invalid user credentials')
+        except models.User.DoesNotExist:
+            raise TeslaAuthException('Invalid user credentials')
+
     def verify_user(self, email, password):
         """
             Validate user credentials
@@ -561,8 +590,26 @@ class Client():
             :exception TeslaAuthException: In case the credentials are not valid
         """
         try:
-            user_info = self.vault.verify_user_password(email, password)
-            user = models.User.objects.get(email=user_info['email'])
+            user = models.User.objects.get(email=email)
+            if not user.is_staff:
+                inst_user = get_institution_user(user)
+                if inst_user is None or not inst_user.login_allowed:
+                    raise TeslaAuthException('User is not allowed to login')
+            authenticated = False
+            if settings.TESLA_PASSWORD_BACKEND == 'DJANGO':
+                if user.check_password(password):
+                    authenticated = True
+                else:
+                    raise TeslaAuthException('Invalid user credentials')
+            if settings.TESLA_PASSWORD_BACKEND == 'VAULT':
+                self.vault.verify_user_password(email, password)
+                authenticated = True
+            if settings.TESLA_PASSWORD_BACKEND == 'DUMMY_EMAIL_PASSWORD':
+                if password != email:
+                    raise TeslaAuthException('Invalid user credentials')
+                authenticated = True
+            if not authenticated:
+                raise TeslaAuthException('Invalid password backend')
         except TeslaVaultException:
             raise TeslaAuthException('Invalid user credentials')
         except models.User.DoesNotExist:
@@ -606,6 +653,8 @@ class Client():
                 scopes.append('/api/v2/institution/{}/learner/{}/*'.format(
                     inst_user.institution_id, inst_user.id
                 ))
+            if not inst_user.inst_admin and not inst_user.login_allowed:
+                raise TeslaAuthException('Login not allowed for this user.')
             token_pair = self.get_user_token_pair(user=inst_user, scope=scopes, ttl=15, max_ttl=24*60)
         else:
             raise TeslaAuthException('Invalid user. Missing Institution or administration rights.')
@@ -1063,13 +1112,24 @@ class Client():
         """
         target_id = None
         token_pair = None
+
+        user_scopes = []
+        user_roles = get_institution_roles(user)
+
+        # Add access to user data
+        user_scopes.append('/api/v2/institution/{}/*'.format(user.institution_id, user.id))
+        if 'LEARNER' in user_roles:
+            # Allow access to LAPI enrolment endpoints
+            user_scopes.append('/lapi/v1/enrolment/{}/{}/'.format(user.institution_id, user.learner.learner_id))
+            user_scopes.append('/lapi/v1/status/{}/{}/'.format(user.institution_id, user.learner.learner_id))
+            user_scopes.append('/lapi/v1/alert/{}/{}/'.format(user.institution_id, user.learner.learner_id))
+
         if target.upper() == 'DASHBOARD':
             target_id = 0
             if ttl is None:
                 ttl = 24 * 60
-            token_pair = self.get_user_token_pair(user=user, scope=['/api/v2/institution/{}/user/{}/*'.format(
-                user.institution_id, user.id
-            )], max_ttl=ttl)
+            token_pair = self.get_user_token_pair(user=user,
+                                                  scope=user_scopes, max_ttl=ttl)
         elif target.upper() == 'LAPI':
             target_id = 1
             if ttl is None:
@@ -1078,17 +1138,65 @@ class Client():
                 learner = user.learner
             except user.learner.RelatedObjectDoesNotExist:
                 raise TeslaAuthException('Provided user is not a learner')
-            token_pair = self.get_learner_token_pair(learner=learner, scope=['/lapi/*'], max_ttl=ttl)
+            token_pair = self.get_learner_token_pair(learner=learner,
+                                                     scope=user_scopes, max_ttl=ttl)
 
         if target_id is None or token_pair is None:
             raise TeslaConfigException('Invalid target type')
 
         expiration = timezone.now() + timezone.timedelta(minutes=ttl)
 
-        launcher =  models.Launcher.objects.create(user=user, token=uuid.uuid4(), session=session, target_url=target_url,
-                                                   token_pair=token_pair, expires_at=expiration)
+        launcher = models.Launcher.objects.create(user=user, token=uuid.uuid4(), session=session, target_url=target_url,
+                                                  token_pair=token_pair, expires_at=expiration)
 
         return {
             'id': launcher.id,
             'token': launcher.token.__str__()
         }
+
+    def get_registered_providers(self, repository="tesla-ce/core", version="main"):
+        """
+            Get the list of registered providers
+
+            :param repository: The repository in GitHub
+            :type repository: str
+            :param version: The branch on the repository
+            :type version: str
+            :return: List of registered providers
+            :rtype: list
+        """
+        return self.deploy.get_registered_providers(repository, version)
+
+    def export_provider_scripts(self, acronym, output, credentials=None, mode=None):
+        """
+            Generates the files required to deploy TeSLA CE VLE on a certain docker orchestrator
+
+            :param acronym: Provider acronym
+            :type type: str
+            :param output: Path to the folder where the scripts will be written
+            :type output: str
+            :param credentials: List of credentials required by this provider
+            :type credentials: list
+            :param mode: The deployment mode (orchestrator) to be used
+            :type mode: str
+        """
+        # Get the orchestrator
+        if mode is None:
+            mode = self.config.config.get('DEPLOYMENT_ORCHESTRATOR')
+
+        # Find Provider
+        try:
+            provider = models.Provider.objects.get(acronym=acronym)
+        except models.Provider.DoesNotExist:
+            raise TeslaConfigException('Invalid provider acronym')
+        files = self.deploy.get_provider_deployment_scripts(provider, mode, credentials=credentials)
+
+        # Write files to disk
+        if not os.path.exists(output):
+            os.makedirs(output)
+        for file in files:
+            out_file = os.path.join(output, file)
+            if not os.path.exists(os.path.dirname(out_file)):
+                os.makedirs(os.path.dirname(out_file))
+            with open(out_file, 'w') as out_fh:
+                out_fh.write(files[file])
